using System;
using System.Collections.Generic;
using System.Linq;
using UnityEngine;

public class CdcHeightCalculator : IAgeCalculator {

    // i index is height in MM starting with 0 maxing out at 2000
    // j index is age in years starting with 2 (index 0) and ending with 20 (last index)
    // value of [i,j] is relative likelihood that height would map to the age

    private const int HeightMinMm = 0;
    private const int HeightMaxMm = 2000;
    private const int HeightIndexMin = 0;
    private const int HeightIndexMax = HeightMaxMm - HeightMinMm;

    private const int AgeYearsMin = 2;
    private const int AgeYearsMax = 25;
    private const int AgeIndexMin = 0;
    private const int AgeIndexMax = AgeYearsMax - AgeYearsMin;

    private static double[,] _ageByHeight = new double[HeightIndexMax + 1, AgeIndexMax + 1];

    public CdcHeightCalculator() {
        try {
            InitializeAgeByHeightTable();
        }
        catch(Exception e) {
            SuperController.LogError($"failed to initialize CdcHeightCalculator: {e.Message}");
        }
    }

    public AgeCalculation GuessFemaleAges(float y) {
        return GuessFemaleAgesAlgo2(y);
    }

    public AgeCalculation GuessMaleAges(float y) {
        return GuessFemaleAges(y);
    }

    public AgeCalculation GuessFemaleAgesAlgo2(float y) {
        var results = new List<AgeGuess>();

        int heightMm = (int)(y * 1000);
        int idxH = heightMm - HeightMinMm;

        if(idxH >= HeightIndexMin && idxH <= HeightIndexMax) {
            for(var idxA = AgeIndexMin; idxA <= AgeIndexMax; idxA++) {
                var ageYear = idxA + AgeYearsMin;
                var confidence = _ageByHeight[idxH, idxA];
                if(confidence <= 0) {
                    continue;
                }

                var guess = new AgeGuess() {
                    Input = y,
                    Age = ageYear,
                    Confidence = (float)confidence
                };

                results.Add(guess);
            }
        }

        if(heightMm > 1710) {
            var fillConfidence = results.Count > 0 ? results.Max(x => x.Confidence) + 0.01f : 1f;
            for(var i = 21; i <= 25; i++) {
                results.Add(new AgeGuess() {
                    Input = y,
                    Age = i,
                    Confidence = fillConfidence
                });
            }
        }

        // scale confidence to 0-1 range
        if(results.Count > 0) {
            var maxConfidence = results.Max(x => x.Confidence);
            var minConfidence = 0;
            if(maxConfidence - minConfidence != 0) {
                for(var i = 0; i < results.Count; i++) {
                    var g = results[i];
                    results[i].Confidence = (results[i].Confidence - minConfidence)/(maxConfidence - minConfidence);
                }
            }
            return new AgeCalculation(results);
        }
        else {
            return null;
        }
    }


    #region data helpers


    private void InitializeAgeByHeightTable() {

        // each row is for a single month of age, expand these out to ever height we want
        // and fill in the data
        // SuperController.singleton.ClearMessages();
        foreach(var row in ReadCsvRow()) {

            // todo: populate table for men
            if(row.IsMale) {
                continue;
            }

            int yearAccumCurrent = -1;
            int yearAccumCounter = 0;
            for(var heightMm = HeightMinMm; heightMm <= HeightMaxMm; heightMm++) {
            	var i = heightMm - HeightMinMm;
            	var j = row.AgeYear - AgeYearsMin;

				if(yearAccumCurrent != row.AgeYear) {
					if(yearAccumCounter != 0) {
						_ageByHeight[i, j] /= yearAccumCounter;
					}
					yearAccumCurrent = row.AgeYear;
					yearAccumCounter = 0;
				}

                var p = row.HeightLikelihood(heightMm, row.CdcL, row.CdcM, row.CdcS);

                // if(row.AgeYear > 16 && heightMm == 1760) {
                //     SuperController.LogMessage($"i={i}, j={j}, age={row.AgeYear}, heightMm={heightMm}, p={p}");
                // }

				_ageByHeight[i,j] += p;
				yearAccumCounter++;
            }
        }
    }

    private class CdcRow {
        public bool IsFemale { get; set; }
        public int AgeMonth { get; set; }
        public float CdcL { get; set; }
        public float CdcM { get; set; }
        public float CdcS { get; set; }
        public int AgeYear { get { return (int)(AgeMonth/12f); } }
        public bool IsMale { get { return !IsFemale; } }
        public double HeightLikelihood(int heightMm, float l, float m, float s) {
            return Math.Round(PercentageForHeight(heightMm / 10f, (heightMm+1)/10f, l, m, s) * 100, 2);
        }
    }

    private static IEnumerable<CdcRow> ReadCsvRow() {
        var lines = _cdcLMSForAge.Split(new [] { '\r', '\n' });
		foreach(var line in lines)
		{
            if(line == "") { continue; }

            string[] columns = line.Split(",".ToCharArray());

            float sex = float.Parse(columns[0]);
            bool isFemale = sex == 2;
            int ageMonth = (int)float.Parse(columns[1]);
            float l = float.Parse(columns[2]);
            float m = float.Parse(columns[3]);
            float s = float.Parse(columns[4]);

            yield return new CdcRow() {
                IsFemale = isFemale,
                AgeMonth = ageMonth,
                CdcL = l,
                CdcM = m, 
                CdcS = s
            };
        }
    }

	private static double PercentageForHeight(double x1, double x2, double l, double m, double s) {
		var percentile1 = ZscoreToPercentile(LmsToZscore(x1, l, m, s));
		var percentile2 = ZscoreToPercentile(LmsToZscore(x2, l, m, s));
		return Math.Abs(percentile1 - percentile2);
	}
	
	private static double LmsToZscore(double x, double l, double m, double s) {
		// https://www.cdc.gov/growthcharts/percentile_data_files.htm
		
		if(l != 0) {
			return (Math.Pow((x / m), l) - 1)/(l * s);
		}
		else {
			return Math.Log(x/m)/s;
		}
	}

	private static double ZscoreToPercentile(double x)
	{
		// constants
		double a1 = 0.254829592;
		double a2 = -0.284496736;
		double a3 = 1.421413741;
		double a4 = -1.453152027;
		double a5 = 1.061405429;
		double p = 0.3275911;
			
		// Save the sign of x
		int sign = 1;
		if (x < 0)
			sign = -1;
		x = Math.Abs(x) / Math.Sqrt(2.0);
			
		// A&S formula 7.1.26
		double t = 1.0 / (1.0 + p*x);
		double y = 1.0 - (((((a5*t + a4)*t) + a3)*t + a2)*t + a1)*t * Math.Exp(-x*x);
			
		var a = 0.5 * (1.0 + sign*y);
		return a;
	}

    // sex (1 - male, 2 - female), ageInMon, L, M, S, percentile stuff i don't care about
	private readonly static string _cdcLMSForAge = @"1,24,0.941523967,86.45220101,0.040321528,79.91084447,80.72977321,81.99171445,84.10289217,86.45220101,88.80524943,90.92619137,92.19687928,93.02265441
1,24.5,1.00720807,86.86160934,0.040395626,80.26037074,81.08868489,82.36400989,84.49470553,86.86160934,89.22804829,91.35753004,92.63176749,93.45923029
1,25.5,0.837251351,87.65247282,0.040577525,81.0052937,81.83445202,83.11387064,85.25887745,87.65247282,90.05675457,92.22966054,93.53406648,94.38278047
1,26.5,0.681492975,88.42326434,0.040723122,81.7341574,82.56406112,83.84716151,86.0051731,88.42326434,90.8626041,93.07608163,94.40884914,95.27761711
1,27.5,0.538779654,89.17549228,0.040833194,82.44845648,83.27898582,84.56534433,86.73506945,89.17549228,91.64711353,93.89827114,95.25754106,96.14511823
1,28.5,0.407697153,89.91040853,0.040909059,83.14944982,83.98045262,85.26961974,87.44977223,89.91040853,92.41159029,94.69757027,96.08148848,96.98662531
1,29.5,0.286762453,90.62907762,0.040952433,83.83819399,84.66948449,85.96098331,88.15028421,90.62907762,93.15718995,95.47522083,96.88197981,97.8034532
1,30.5,0.174489485,91.33242379,0.04096533,84.51558277,85.3469433,86.64027154,88.83745411,91.33242379,93.88495599,96.23239427,97.66026663,98.59690538
1,31.5,0.069444521,92.02127167,0.040949976,85.18238019,86.01356554,87.30820085,89.5120186,92.02127167,94.59585394,96.97021533,98.4175791,99.36828331
1,32.5,-0.029720564,92.69637946,0.040908737,85.83925011,86.66999332,87.96540055,90.17463683,92.69637946,95.29079906,97.68978097,99.15513792,100.1188932
1,33.5,-0.124251789,93.35846546,0.040844062,86.48678276,87.31680155,88.61244073,90.82591867,93.35846546,95.97067824,98.39217521,99.87416352,100.8500508
1,34.5,-0.215288396,94.00822923,0.040758431,87.12551862,87.95452162,89.24985581,91.46644774,94.00822923,96.63636727,99.0784807,100.5758831,101.5630853
1,35.5,-0.30385434,94.64636981,0.040654312,87.75596799,88.58366128,89.87816458,92.09680119,94.64636981,97.28874542,99.74978771,101.2615351,102.2593402
1,36.5,-0.390918369,95.27359106,0.04053412,88.37863651,89.20472611,90.49788649,92.71755946,95.27359106,97.92869928,100.4071992,101.9323762,102.940182
1,37.5,-0.254801167,95.91474929,0.040572876,88.93297086,89.77301106,91.08607735,93.33440049,95.91474929,98.58524582,101.0690065,102.5930445,103.5982668
1,38.5,-0.125654535,96.54734328,0.04061691,89.47916294,90.33305814,91.66588835,93.94268367,96.54734328,99.23357783,101.7233762,103.2470198,104.2502776
1,39.5,-0.00316735,97.17191309,0.040666414,90.01765704,90.88532031,92.23778882,94.54291151,97.17191309,99.87425862,102.3708617,103.8948257,104.8967054
1,40.5,0.11291221,97.78897727,0.040721467,90.54890623,91.43025486,92.80224597,95.1355744,97.78897727,100.5078239,103.011988,104.5369608,105.5380208
1,41.5,0.222754969,98.3990283,0.040782045,91.07337426,91.96832362,93.35972283,95.72114636,98.3990283,101.1347788,103.6472524,105.1739016,106.1746779
1,42.5,0.326530126,99.00254338,0.040848042,91.59152368,92.4999858,93.91067749,96.30009195,99.00254338,101.7556073,104.2771267,105.8060983,106.8071048
1,43.5,0.42436156,99.599977,0.040919281,92.10382052,93.02569976,94.45556109,96.87286014,99.599977,102.370767,104.9020571,106.4339786,107.4357106
1,44.5,0.516353108,100.191764,0.040995524,92.6107295,93.54591978,94.99481672,97.43988586,100.191764,102.9806917,105.5224653,107.0579468,108.0608826
1,45.5,0.602595306,100.7783198,0.041076485,93.11271174,94.06109422,95.52887815,98.00158958,100.7783198,103.5857927,106.1387493,107.6783842,108.6829866
1,46.5,0.683170764,101.3600411,0.041161838,93.61022262,94.57166376,96.05816868,98.55837705,101.3600411,104.186459,106.7512837,108.2956497,109.3023669
1,47.5,0.758158406,101.9373058,0.041251224,94.10370972,95.07805975,96.58310008,99.11063889,101.9373058,104.7830584,107.3604207,108.9100797,109.9193463
1,48.5,0.827636736,102.5104735,0.041344257,94.59361093,95.58070273,97.1040715,99.65875031,102.5104735,105.3759377,107.9664906,109.5219891,110.5342263
1,49.5,0.891686306,103.0798852,0.041440534,95.08035263,96.08000091,97.62146857,100.2030707,103.0798852,105.9654232,108.569802,110.1316713,111.1472879
1,50.5,0.95039153,103.645864,0.041539635,95.56434805,96.57634888,98.13566246,100.7439435,103.645864,106.5518212,109.1706428,110.7393989,111.7587911
1,51.5,1.003830006,104.208713,0.041641136,96.04599748,97.07012724,98.64700876,101.281694,104.208713,107.1354171,109.76928,111.3454248,112.3689778
1,52.5,1.05213569,104.7687256,0.041744602,96.52567713,97.56169654,99.15584797,101.8166373,104.7687256,107.7164829,110.3659614,111.9499779,112.9780622
1,53.5,1.0953669,105.3261638,0.041849607,97.00375833,98.05140652,99.66250203,102.3490611,105.3261638,108.2952617,110.9609139,112.5532737,113.5862516
1,54.5,1.133652119,105.8812823,0.041955723,97.48058355,98.53958366,100.1672766,102.8792439,105.8812823,108.8719858,111.5543461,113.1555037,114.1937245
1,55.5,1.167104213,106.4343146,0.042062532,97.95647862,99.026537,100.6704587,103.4074438,106.4343146,109.4468665,112.1464475,113.7568423,114.800644
1,56.5,1.195845353,106.9854769,0.042169628,98.43174768,99.51255522,101.1723164,103.9339016,106.9854769,110.0200973,112.7373894,114.3574452,115.4071549
1,57.5,1.220004233,107.534968,0.042276619,98.90667254,99.99790605,101.6730987,104.4588401,107.534968,110.5918541,113.327325,114.9574502,116.0133837
1,58.5,1.239715856,108.0829695,0.042383129,99.3815118,100.4828356,102.1730346,104.9824642,108.0829695,111.1622955,113.9163901,115.5569776,116.6194398
1,59.5,1.255121285,108.6296457,0.042488804,99.85650001,100.9675675,102.6723326,105.5049607,108.6296457,111.731563,114.5047033,116.1561304,117.2254154
1,60.5,1.266367398,109.1751441,0.042593311,100.331847,101.4523027,103.171181,106.026498,109.1751441,112.2997816,115.0923665,116.7549954,117.831386
1,61.5,1.273606657,109.7195954,0.042696342,100.8077371,101.9372185,103.6697469,106.5472265,109.7195954,112.86706,115.6794655,117.3536426,118.4374113
1,62.5,1.276996893,110.2631136,0.042797615,101.2843288,102.4224687,104.1681762,107.0672782,110.2631136,113.4334909,116.2660704,117.9521268,119.0435349
1,63.5,1.276701119,110.8057967,0.042896877,101.7617545,102.908183,104.6665937,107.5867669,110.8057967,113.9991516,116.8522359,118.5504872,119.6497853
1,64.5,1.272887366,111.3477265,0.042993904,102.2401199,103.3944666,105.1651027,108.1057886,111.3477265,114.5641044,117.4380018,119.1487482,120.2561762
1,65.5,1.265728536,111.8889694,0.043088503,102.719504,103.8814006,105.6637849,108.6244211,111.8889694,115.128397,118.0233939,119.7469201,120.8627069
1,66.5,1.255402281,112.4295761,0.043180513,103.1999595,104.3690418,106.1627011,109.1427246,112.4295761,115.6920629,118.6084238,120.3449993,121.4693629
1,67.5,1.242090871,112.9695827,0.043269806,103.6815122,104.8574227,106.6618905,109.6607418,112.9695827,116.2551221,119.1930903,120.9429688,122.0761162
1,68.5,1.225981067,113.5090108,0.043356287,104.164162,105.3465519,107.1613717,110.1784984,113.5090108,116.8175812,119.777379,121.540799,122.682926
1,69.5,1.207263978,114.0478678,0.043439893,104.6478827,105.8364145,107.6611426,110.6960031,114.0478678,117.3794345,120.3612638,122.1384479,123.2897392
1,70.5,1.186140222,114.5861486,0.043520597,105.1326221,106.3269721,108.1611811,111.2132492,114.5861486,117.9406648,120.9447067,122.7358617,123.8964899
1,71.5,1.162796198,115.1238315,0.043598407,105.6183068,106.8181654,108.6614449,111.7302112,115.1238315,118.5012409,121.5276587,123.3329768,124.5031042
1,72.5,1.137442868,115.6608862,0.043673359,106.1048359,107.3099116,109.1618735,112.2468516,115.6608862,119.0611237,122.1100607,123.9297176,125.1094938
1,73.5,1.110286487,116.1972691,0.043745523,106.592087,107.8021076,109.6623876,112.7631168,116.1972691,119.6202624,122.6918435,124.5259991,125.7155618
1,74.5,1.081536236,116.732925,0.043815003,107.0799166,108.2946307,110.1628906,113.2789389,116.732925,120.1785968,123.272929,125.1217272,126.3212019
1,75.5,1.05140374,117.2677879,0.043881929,107.5681606,108.7873391,110.6632694,113.7942368,117.2677879,120.7360574,123.8532304,125.7167992,126.926299
1,76.5,1.020102497,117.8017819,0.043946461,108.0566359,109.2800738,111.1633949,114.3089166,117.8017819,121.2925663,124.4326533,126.3111047,127.5307299
1,77.5,0.987847213,118.3348215,0.044008785,108.5451423,109.7726591,111.6631239,114.8228726,118.3348215,121.8480376,125.0110959,126.9045258,128.134364
1,78.5,0.954853043,118.8668123,0.044069112,109.0334636,110.2649049,112.1622995,115.335988,118.8668123,122.4023786,125.5884499,127.4969382,128.737064
1,79.5,0.921334742,119.397652,0.044127675,109.5213695,110.7566073,112.6607528,115.8481358,119.397652,122.9554895,126.1646012,128.0882119,129.3386866
1,80.5,0.887505723,119.9272309,0.044184725,110.0086174,111.247551,113.158304,116.3591802,119.9272309,123.5072652,126.7394306,128.6782115,129.9390834
1,81.5,0.85357703,120.455433,0.044240532,110.4949545,111.7375104,113.654764,116.8689769,120.455433,124.057595,127.3128143,129.2667977,130.5381015
1,82.5,0.819756239,120.9821362,0.044295379,110.9801192,112.2262515,114.1499353,117.3773747,120.9821362,124.6063638,127.8846249,129.8538272,131.1355844
1,83.5,0.786246296,121.5072136,0.044349559,111.4638437,112.7135338,114.6436141,117.8842164,121.5072136,125.1534527,128.4547316,130.4391542,131.7313729
1,84.5,0.753244292,122.0305342,0.044403374,111.9458554,113.1991118,115.1355915,118.3893397,122.0305342,125.6987395,129.0230015,131.0226304,132.3253057
1,85.5,0.720940222,122.5519634,0.04445713,112.4258796,113.6827373,115.625655,118.8925788,122.5519634,126.2420996,129.5892999,131.6041067,132.9172205
1,86.5,0.689515708,123.0713645,0.044511135,112.9036412,114.1641607,116.1135904,119.3937653,123.0713645,126.7834065,130.153491,132.183433,133.5069548
1,87.5,0.659142731,123.588599,0.044565693,113.3788664,114.6431334,116.5991827,119.8927292,123.588599,127.3225327,130.7154389,132.7604599,134.0943467
1,88.5,0.629997853,124.1035312,0.044621104,113.8512827,115.1194078,117.0822191,120.3893032,124.1035312,127.8593529,131.2750083,133.335037,134.6792321
1,89.5,0.602203984,124.6160161,0.044677662,114.3206308,115.5927447,117.562488,120.8833137,124.6160161,128.393735,131.8320643,133.9070206,135.2614591
1,90.5,0.575908038,125.1259182,0.044735646,114.7866522,116.0629074,118.0397834,121.3745956,125.1259182,128.9255543,132.3864745,134.4762655,135.8408704
1,91.5,0.55123134,125.6331012,0.044795322,115.2491001,116.5296686,118.5139049,121.8629855,125.6331012,129.4546858,132.9381089,135.0426312,136.4173156
1,92.5,0.528279901,126.1374319,0.044856941,115.7077388,116.9928104,118.9846594,122.3483243,126.1374319,129.9810071,133.4868407,135.6059815,136.9906494
1,93.5,0.507143576,126.6387804,0.04492073,116.1623461,117.4521263,119.4518627,122.8304588,126.6387804,130.504399,134.0325473,136.1661852,137.5607324
1,94.5,0.487895344,127.1370217,0.044986899,116.6127146,117.9074226,119.9153408,123.3092425,127.1370217,131.024746,134.5751108,136.7231173,138.1274323
1,95.5,0.470590753,127.6320362,0.045055632,117.0586529,118.3585201,120.3749315,123.784537,127.6320362,131.5419375,135.1144188,137.2766592,138.6906245
1,96.5,0.455267507,128.1237104,0.045127088,117.4999879,118.8052553,120.830485,124.2562127,128.1237104,132.0558684,135.6503652,137.8267001,139.2501934
1,97.5,0.441945241,128.6119383,0.045201399,117.9365657,119.2474816,121.281866,124.7241502,128.6119383,132.5664397,136.1828511,138.3731376,139.8060325
1,98.5,0.430625458,129.096622,0.045278671,118.3682526,119.6850711,121.7289543,125.1882412,129.096622,133.0735595,136.7117853,138.9158785,140.3580462
1,99.5,0.421291648,129.5776723,0.045358979,118.794937,120.1179149,122.1716458,125.6483893,129.5776723,133.5771438,137.2370854,139.4548395,140.9061502
1,100.5,0.413909588,130.0550101,0.045442372,119.2165297,120.5459248,122.6098539,126.1045113,130.0550101,134.0771172,137.7586784,139.9899485,141.4502723
1,101.5,0.408427813,130.5285669,0.045528869,119.6329654,120.9690339,123.04351,126.5565377,130.5285669,134.5734138,138.2765017,140.5211451,141.9903534
1,102.5,0.404778262,130.9982857,0.045618459,120.0442031,121.3871973,123.4725646,127.0044134,130.9982857,135.065978,138.7905039,141.0483813,142.5263486
1,103.5,0.402877077,131.4641218,0.045711105,120.450227,121.8003934,123.896988,127.4480994,131.4641218,135.5547656,139.3006456,141.5716229,143.0582274
1,104.5,0.402625561,131.9260439,0.045806742,120.8510473,122.2086239,124.3167709,127.8875724,131.9260439,136.0397444,139.8069003,142.0908498,143.5859753
1,105.5,0.40391127,132.3840348,0.045905281,121.2467001,122.6119145,124.7319249,128.3228265,132.3840348,136.5208952,140.3092555,142.6060571,144.109594
1,106.5,0.406609232,132.838092,0.046006604,121.6372483,123.0103156,125.1424835,128.7538732,132.838092,136.9982129,140.8077133,143.1172562,144.6291028
1,107.5,0.410583274,133.2882291,0.046110573,122.0227817,123.4039024,125.5485022,129.1807426,133.2882291,137.4717069,141.3022916,143.6244753,145.1445387
1,108.5,0.415687443,133.7344759,0.046217028,122.4034171,123.7927752,125.9500588,129.6034839,133.7344759,137.9414029,141.793025,144.1277605,145.6559581
1,109.5,0.421767514,134.1768801,0.04632579,122.7792983,124.1770596,126.3472542,130.0221657,134.1768801,138.4073433,142.2799654,144.6271767,146.1634368
1,110.5,0.428662551,134.6155076,0.046436662,123.1505962,124.5569064,126.7402123,130.436877,134.6155076,138.8695881,142.7631838,145.1228083,146.6670713
1,111.5,0.436206531,135.0504433,0.04654943,123.5175084,124.9324922,127.1290805,130.8477278,135.0504433,139.3282163,143.2427702,145.6147602,147.1669794
1,112.5,0.44423,135.4817925,0.046663871,123.8802592,125.3040185,127.5140299,131.2548494,135.4817925,139.7833266,143.7188356,146.103159,147.6633011
1,113.5,0.45256176,135.9096813,0.046779748,124.2390993,125.6717122,127.8952551,131.6583952,135.9096813,140.2350389,144.1915122,146.5881531,148.1561991
1,114.5,0.461030578,136.3342577,0.046896817,124.5943049,126.035825,128.2729746,132.0585409,136.3342577,140.6834944,144.6609548,147.0699143,148.6458598
1,115.5,0.469466904,136.7556923,0.047014827,124.9461775,126.3966334,128.6474311,132.4554857,136.7556923,141.1288576,145.1273417,147.5486382,149.132494
1,116.5,0.477704608,137.1741794,0.047133525,125.2950434,126.7544381,129.0188908,132.8494521,137.1741794,141.5713168,145.5908755,148.0245452,149.6163372
1,117.5,0.48558272,137.5899378,0.047252654,125.6412524,127.1095636,129.3876441,133.2406866,137.5899378,142.011085,146.0517839,148.4978811,150.0976507
1,118.5,0.492947182,138.0032114,0.047371961,125.9851773,127.4623576,129.7540048,133.6294604,138.0032114,142.4484014,146.510321,148.9689178,150.5767217
1,119.5,0.499652617,138.4142703,0.047491194,126.3272131,127.8131904,130.1183106,134.0160697,138.4142703,142.8835317,146.9667676,149.4379538,151.0538639
1,120.5,0.505564115,138.8234114,0.047610108,126.6677753,128.1624542,130.4809221,134.4008357,138.8234114,143.3167691,147.421432,149.9053151,151.5294179
1,121.5,0.510559047,139.2309592,0.047728463,127.0072991,128.5105623,130.8422234,134.7841054,139.2309592,143.7484354,147.8746507,150.3713549,152.0037511
1,122.5,0.514528903,139.6372663,0.04784603,127.3462381,128.857948,131.2026207,135.1662516,139.6372663,144.1788815,148.326789,150.8364543,152.4772579
1,123.5,0.517381177,140.042714,0.047962592,127.6850624,129.2050634,131.5625423,135.5476732,140.042714,144.6084877,148.7782409,151.3010223,152.9503596
1,124.5,0.519041285,140.4477127,0.048077942,128.0242572,129.5523785,131.9224379,135.9287948,140.4477127,145.0376645,149.2294296,151.7654951,153.4235035
1,125.5,0.519454524,140.8527022,0.048191889,128.3643208,129.9003795,132.2827776,136.3100669,140.8527022,145.4668527,149.6808068,152.2303363,153.8971624
1,126.5,0.518588072,141.2581515,0.048304259,128.7057627,130.2495672,132.6440511,136.6919657,141.2581515,145.8965233,150.1328531,152.6960355,154.3718335
1,127.5,0.516433004,141.6645592,0.048414893,129.0491015,130.6004555,133.0067661,137.0749922,141.6645592,146.3271773,150.5860767,153.1631074,154.8480367
1,128.5,0.513006312,142.072452,0.048523648,129.394862,130.9535693,133.3714475,137.4596717,142.072452,146.7593449,151.0410123,153.6320904,155.3263129
1,129.5,0.508352901,142.4823852,0.048630402,129.7435732,131.309442,133.738635,137.8465525,142.4823852,147.1935849,151.4982199,154.103544,155.8072211
1,130.5,0.502547502,142.8949403,0.04873505,130.095765,131.6686134,134.1088817,138.2362048,142.8949403,147.630483,151.9582822,154.5780465,156.2913356
1,131.5,0.495696454,143.3107241,0.048837504,130.4519655,132.031627,134.4827517,138.6292185,143.3107241,148.07065,152.4218027,155.0561919,156.7792423
1,132.5,0.487939275,143.7303663,0.048937694,130.8126976,132.3990267,134.8608171,139.0262015,143.7303663,148.5147188,152.8894016,155.5385858,157.2715342
1,133.5,0.479449924,144.1545167,0.049035564,131.1784756,132.771354,135.2436555,139.4277761,144.1545167,148.9633421,153.3617127,156.0258407,157.7688063
1,134.5,0.470437652,144.5838414,0.049131073,131.5498015,133.1491442,135.6318463,139.8345767,144.5838414,149.4171874,153.839378,156.5185711,158.27165
1,135.5,0.461147305,145.0190192,0.049224189,131.9271616,133.5329226,136.0259671,140.2472448,145.0190192,149.876933,154.3230425,157.0173867,158.7806462
1,136.5,0.451858946,145.4607359,0.049314887,132.311022,133.9232006,136.4265892,140.6664253,145.4607359,150.3432618,154.8133474,157.522886,159.2963578
1,137.5,0.442886661,145.9096784,0.049403145,132.7018251,134.3204714,136.8342729,141.0927603,145.9096784,150.8168546,155.3109233,158.0356481,159.8193221
1,138.5,0.434576385,146.3665278,0.049488934,133.0999854,134.7252055,137.2495627,141.5268837,146.3665278,151.2983826,155.8163811,158.5562242,160.3500415
1,139.5,0.427302633,146.8319513,0.049572216,133.5058853,135.1378458,137.6729811,141.9694138,146.8319513,151.7884983,156.3303034,159.085128,160.8889743
1,140.5,0.421464027,147.3065929,0.049652935,133.9198714,135.5588028,138.1050231,142.4209457,147.3065929,152.2878255,156.8532337,159.622826,161.4365245
1,141.5,0.417477538,147.7910635,0.049731004,134.34225,135.9884501,138.5461496,142.8820429,147.7910635,152.7969484,157.3856659,160.1697263,161.993032
1,142.5,0.415771438,148.2859294,0.0498063,134.773284,136.4271185,138.9967803,143.353228,148.2859294,153.3163996,157.9280318,160.7261679,162.5587616
1,143.5,0.416777012,148.7917006,0.04987865,135.2131887,136.8750919,139.4572873,143.8349727,148.7917006,153.8466466,158.4806894,161.2924091,163.133893
1,144.5,0.420919142,149.3088178,0.049947823,135.6621289,137.3326017,139.9279871,144.3276874,149.3088178,154.3880792,159.0439098,161.8686162,163.7185106
1,145.5,0.428606007,149.8376391,0.050013518,136.1202156,137.7998222,140.409134,144.8317108,149.8376391,154.9409947,159.6178646,162.4548526,164.3125939
1,146.5,0.440218167,150.3784267,0.050075353,136.5875035,138.2768661,140.9009122,145.3472981,150.3784267,155.505584,160.2026132,163.0510679,164.9160089
1,147.5,0.456097443,150.9313331,0.050132858,137.0639883,138.7637799,141.403429,145.8746111,150.9313331,156.0819181,160.7980913,163.657089,165.5285004
1,148.5,0.476536014,151.4963887,0.050185471,137.5496052,139.2605402,141.9167079,146.4137069,151.4963887,156.6699351,161.4041,164.2726114,166.1496863
1,149.5,0.501766234,152.0734897,0.050232532,138.0442266,139.7670498,142.4406823,146.9645285,152.0734897,157.2694285,162.0202967,164.897193,166.7790531
1,150.5,0.531951655,152.6623878,0.050273285,138.5476617,140.2831346,142.9751899,147.5268957,152.6623878,157.8800378,162.6461885,165.5302497,167.4159536
1,151.5,0.567179725,153.2626819,0.050306885,139.0596548,140.8085414,143.5199675,148.1004983,153.2626819,158.5012409,163.2811271,166.1710534,168.0596069
1,152.5,0.607456565,153.8738124,0.050332406,139.5798855,141.3429356,144.0746481,148.6848902,153.8738124,159.1323501,163.9243081,166.8187329,168.7091009
1,153.5,0.652704121,154.495058,0.05034886,140.1079685,141.8859002,144.6387576,149.2794857,154.495058,159.7725112,164.5747721,167.4722776,169.3633976
1,154.5,0.702759868,155.1255365,0.050355216,140.6434536,142.4369354,145.2117144,149.8835591,155.1255365,160.4207062,165.2314109,168.1305444,170.0213408
1,155.5,0.757379106,155.7642086,0.050350423,141.1858268,142.9954591,145.7928297,150.4962462,155.7642086,161.0757603,165.892976,168.7922681,170.6816665
1,156.5,0.816239713,156.4098858,0.050333444,141.7345116,143.5608087,146.3813098,151.1165487,156.4098858,161.7363527,166.5580917,169.4560742,171.3430163
1,157.5,0.878947416,157.0612415,0.050303283,142.2888712,144.1322433,146.9762604,151.7433416,157.0612415,162.4010311,167.2252714,170.1204959,172.0039535
1,158.5,0.945053486,157.7168289,0.050259018,142.8482077,144.7089466,147.576693,152.3753859,157.7168289,163.0682321,167.8929368,170.7839909,172.662978
1,159.5,1.014046108,158.3750929,0.050199837,143.4117718,145.2900346,148.1815319,153.0113368,158.3750929,163.7362982,168.5594402,171.444966,173.3185527
1,160.5,1.085383319,159.034399,0.050125062,143.9787585,145.8745579,148.7896253,153.6497654,159.034399,164.4035075,169.2230883,172.1017957,173.9691164
1,161.5,1.158487278,159.6930501,0.05003418,144.5483179,146.4615117,149.3997554,154.2891719,159.6930501,165.0680948,169.8821678,172.7528491,174.6131123
1,162.5,1.232768816,160.3493168,0.049926861,145.1195552,147.0498421,150.0106525,154.9280091,160.3493168,165.7282823,170.5349712,173.3965112,175.2490052
1,163.5,1.307628899,161.0014586,0.049802977,145.6915401,147.6384567,150.6210083,155.5647003,161.0014586,166.3823042,171.1798224,174.0312083,175.8753066
1,164.5,1.382473225,161.6477515,0.04966261,146.2633119,148.226234,151.2294913,156.1976616,161.6477515,167.0284338,171.8151013,174.6554295,176.490594
1,165.5,1.456720479,162.2865119,0.049506051,146.8338868,148.8120346,151.8347622,156.8253238,162.2865119,167.6650085,172.4392666,175.2677481,177.0935299
1,166.5,1.529810247,162.9161202,0.049333801,147.4022657,149.394712,152.4354895,157.4461523,162.9161202,168.2904522,173.0508762,175.8668393,177.6828795
1,167.5,1.601219573,163.535045,0.049146553,147.9674393,149.9731226,153.0303654,158.0586697,163.535045,168.9032981,173.6486051,176.4514947,178.2575211
1,168.5,1.670433444,164.1418486,0.04894519,148.5284089,150.5461431,153.6181187,158.6614636,164.1418486,169.5021963,174.2312589,177.0206409,178.8164693
1,169.5,1.736995571,164.7352199,0.048730749,149.0841789,151.1126739,154.1975312,159.2532157,164.7352199,170.0859388,174.7977852,177.5733406,179.3588685
1,170.5,1.800483802,165.3139755,0.048504404,149.6337753,151.6716544,154.7674484,159.8327068,165.3139755,170.6534628,175.347281,178.1088034,179.8840066
1,171.5,1.860518777,165.8770715,0.048267442,150.1762526,152.2220718,155.3267913,160.3988301,165.8770715,171.2038574,175.8789961,178.6263873,180.3913154
1,172.5,1.916765525,166.4236087,0.04802123,150.7107013,152.7629701,155.874565,160.9505985,166.4236087,171.7363673,176.392334,179.1255987,180.8803698
1,173.5,1.968934444,166.9528354,0.047767192,151.2362566,153.2934582,156.4098665,161.4871507,166.9528354,172.2503918,176.8868489,179.6060885,181.3508837
1,174.5,2.016781776,167.4641466,0.047506783,151.7521046,153.8127163,156.9318906,162.0077536,167.4641466,172.7454817,177.3622413,180.0676464,181.8027041
1,175.5,2.060109658,167.9570814,0.047241456,152.2574887,154.3200013,157.4399327,162.5118031,167.9570814,173.2213335,177.8183499,180.5101936,182.2358034
1,176.5,2.098765817,168.4313175,0.04697265,152.7517151,154.814651,157.9333914,162.9988222,168.4313175,173.6777819,178.2551431,180.9337725,182.6502694
1,177.5,2.132642948,168.8866644,0.046701759,153.2341567,155.2960861,158.4117685,163.4684575,168.8866644,174.1147899,178.6727081,181.3385364,183.0462946
1,178.5,2.16167779,169.3230548,0.046430122,153.7042563,155.7638123,158.8746672,163.9204738,169.3230548,174.5324388,179.0712394,181.7247376,183.4241646
1,179.5,2.185849904,169.7405351,0.046159004,154.1615288,156.2174196,159.3217901,164.3547479,169.7405351,174.9309165,179.4510272,182.0927156,183.7842466
1,180.5,2.205180153,170.139255,0.045889585,154.6055622,156.6565818,159.7529343,164.7712603,170.139255,175.310506,179.8124447,182.4428851,184.1269767
1,181.5,2.219728869,170.5194567,0.045622955,155.0360175,157.0810539,160.1679874,165.1700873,170.5194567,175.6715733,180.1559363,182.7757235,184.4528488
1,182.5,2.2295937,170.881464,0.045360101,155.452628,157.4906696,160.5669211,165.5513919,170.881464,176.0145556,180.4820061,183.09176,184.7624031
1,183.5,2.234907144,171.2256717,0.045101913,155.8551976,157.8853369,160.9497852,165.9154147,171.2256717,176.3399504,180.791206,183.3915648,185.0562159
1,184.5,2.235833767,171.5525345,0.044849174,156.243598,158.2650343,161.3167006,166.2624644,171.5525345,176.648304,181.0841263,183.6757386,185.3348893
1,185.5,2.232567138,171.8625576,0.044602566,156.6177662,158.6298055,161.6678528,166.5929092,171.8625576,176.9402021,181.3613851,183.9449038,185.5990431
1,186.5,2.2253265,172.1562865,0.044362674,156.9777005,158.9797544,162.0034846,166.9071674,172.1562865,177.2162598,181.6236202,184.1996965,185.8493063
1,187.5,2.214353232,172.4342983,0.044129985,157.3234565,159.31504,162.3238889,167.2056993,172.4342983,177.4771134,181.871481,184.4407585,186.0863109
1,188.5,2.199905902,172.6971935,0.043904897,157.6551432,159.6358703,162.6294022,167.4889986,172.6971935,177.7234122,182.1056218,184.6687321,186.3106859
1,189.5,2.182262864,172.9455898,0.043687723,157.9729166,159.9424968,162.9203983,167.7575872,172.9455898,177.9558135,182.3266957,184.8842531,186.5230505
1,190.5,2.161704969,173.180112,0.043478698,158.2769793,160.2352102,163.1972811,168.012004,173.180112,178.174973,182.5353493,185.0879485,186.7240141
1,191.5,2.138524662,173.4013896,0.043277987,158.5675712,160.5143338,163.4604795,168.2528029,173.4013896,178.381543,182.7322187,185.2804307,186.914169
1,192.5,2.113023423,173.6100518,0.043085685,158.8449655,160.7802183,163.7104424,168.4805469,173.6100518,178.5761676,182.9179257,185.4622948,187.0940877
1,193.5,2.085490286,173.8067179,0.042901835,159.1094689,161.0332391,163.9476322,168.6957988,173.8067179,178.7594756,183.093075,185.6341183,187.2643258
1,194.5,2.0562195,173.9919998,0.042726424,159.3614112,161.2737894,164.1725219,168.8991222,173.9919998,178.9320817,183.2582518,185.7964565,187.4254148
1,195.5,2.025496648,174.1664951,0.042559396,159.6011441,161.5022772,164.3855897,169.0910747,174.1664951,179.0945815,183.4140202,185.949843,187.5778643
1,196.5,1.993598182,174.3307855,0.042400652,159.8290369,161.7191211,164.5873165,169.2722058,174.3307855,179.2475503,183.5609217,186.0947883,187.7221607
1,197.5,1.960789092,174.4854344,0.042250063,160.0454725,161.9247473,164.7781818,169.4430536,174.4854344,179.3915415,183.6994748,186.2317794,187.8587671
1,198.5,1.927320937,174.6309856,0.042107465,160.2508441,162.1195857,164.9586613,169.6041427,174.6309856,179.5270853,183.8301738,186.3612801,187.9881233
1,199.5,1.89343024,174.7679617,0.041972676,160.4455519,162.3040676,165.1292244,169.7559826,174.7679617,179.6546885,183.9534894,186.4837302,188.1106465
1,200.5,1.859337259,174.8968634,0.041845488,160.6300005,162.4786229,165.2903324,169.8990665,174.8968634,179.7748338,184.0698683,186.5995468,188.2267311
1,201.5,1.825245107,175.0181691,0.041725679,160.8045956,162.643678,165.4424364,170.0338694,175.0181691,179.8879797,184.1797333,186.7091242,188.3367503
1,202.5,1.791339209,175.1323345,0.041613015,160.9697424,162.7996536,165.5859761,170.1608483,175.1323345,179.9945609,184.2834844,186.8128348,188.4410559
1,203.5,1.757787065,175.2397926,0.041507249,161.1258433,162.9469636,165.7213786,170.280441,175.2397926,180.0949883,184.3814989,186.9110296,188.5399798
1,204.5,1.724738292,175.340954,0.041408129,161.2732955,163.0860132,165.8490577,170.3930664,175.340954,180.1896498,184.4741322,187.0040394,188.6338345
1,205.5,1.692324905,175.4362071,0.041315398,161.4124903,163.2171976,165.9694129,170.4991239,175.4362071,180.278911,184.5617185,187.0921753,188.7229142
1,206.5,1.660661815,175.5259191,0.041228796,161.5438112,163.3409016,166.0828291,170.5989941,175.5259191,180.3631154,184.644572,187.1757295,188.8074955
1,207.5,1.629847495,175.6104358,0.04114806,161.6676329,163.4574984,166.1896765,170.6930385,175.6104358,180.4425858,184.7229873,187.2549767,188.8878386
1,208.5,1.599964788,175.690083,0.041072931,161.7843202,163.5673489,166.29031,170.7816002,175.690083,180.5176249,184.7972407,187.3301745,188.9641878
1,209.5,1.571081817,175.7651671,0.04100315,161.8942273,163.6708019,166.3850695,170.8650043,175.7651671,180.5885165,184.867591,187.4015645,189.0367727
1,210.5,1.543252982,175.8359757,0.040938463,161.9976976,163.7681929,166.4742799,170.9435584,175.8359757,180.6555257,184.9342803,187.4693732,189.1058089
1,211.5,1.516519998,175.9027788,0.040878617,162.0950624,163.8598446,166.5582511,171.0175531,175.9027788,180.7189006,184.9975349,187.5338128,189.1714988
1,212.5,1.490912963,175.9658293,0.040823368,162.1866414,163.9460665,166.6372787,171.0872629,175.9658293,180.7788732,185.0575666,187.5950821,189.2340323
1,213.5,1.466451429,176.0253641,0.040772475,162.272742,164.027155,166.7116437,171.1529465,176.0253641,180.8356596,185.114573,187.6533672,189.2935878
1,214.5,1.44314546,176.081605,0.040725706,162.3536592,164.1033935,166.7816133,171.2148477,176.081605,180.8894616,185.1687386,187.7088422,189.3503326
1,215.5,1.420996665,176.1347593,0.040682834,162.429676,164.1750527,166.8474411,171.2731962,176.1347593,180.9404676,185.2202359,187.7616702,189.4044237
1,216.5,1.399999187,176.1850208,0.04064364,162.501063,164.2423904,166.9093676,171.3282079,176.1850208,180.9888527,185.2692255,187.8120038,189.4560086
1,217.5,1.380140651,176.2325707,0.040607913,162.5680787,164.3056523,166.9676208,171.3800858,176.2325707,181.0347806,185.3158575,187.8599859,189.5052256
1,218.5,1.361403047,176.2775781,0.040575448,162.6309697,164.365072,167.0224162,171.4290208,176.2775781,181.0784033,185.3602719,187.9057499,189.5522044
1,219.5,1.343763564,176.3202008,0.040546051,162.689971,164.4208714,167.0739579,171.4751921,176.3202008,181.1198626,185.4025992,187.9494211,189.5970671
1,220.5,1.327195355,176.3605864,0.040519532,162.7453061,164.473261,167.1224387,171.5187679,176.3605864,181.1592906,185.4429613,187.9911165,189.6399279
1,221.5,1.311668242,176.3988725,0.040495713,162.7971876,164.5224406,167.1680405,171.5599062,176.3988725,181.1968103,185.4814718,188.0309455,189.6808943
1,222.5,1.297149359,176.4351874,0.040474421,162.8458172,164.5685992,167.2109353,171.598755,176.4351874,181.232536,185.5182368,188.0690108,189.7200672
1,223.5,1.283603728,176.469651,0.040455493,162.8913862,164.6119158,167.251285,171.6354533,176.469651,181.2665744,185.5533551,188.1054085,189.7575413
1,224.5,1.270994782,176.5023751,0.040438773,162.9340759,164.6525596,167.2892424,171.6701314,176.5023751,181.2990249,185.5869193,188.1402284,189.7934056
1,225.5,1.25928483,176.533464,0.040424111,162.9740581,164.6906907,167.3249515,171.7029114,176.533464,181.3299799,185.6190155,188.1735549,189.8277438
1,226.5,1.248435461,176.5630153,0.040411366,163.0114951,164.72646,167.3585477,171.7339076,176.5630153,181.3595256,185.6497244,188.2054669,189.8606344
1,227.5,1.23840791,176.5911197,0.040400405,163.0465405,164.7600102,167.3901586,171.7632274,176.5911197,181.3877426,185.6791212,188.2360386,189.8921514
1,228.5,1.229163362,176.6178621,0.040391101,163.0793392,164.7914756,167.4199044,171.7909712,176.6178621,181.4147056,185.7072763,188.2653392,189.9223642
1,229.5,1.220663228,176.6433219,0.040383334,163.1100283,164.8209832,167.4478978,171.8172333,176.6433219,181.4404846,185.7342556,188.293434,189.9513383
1,230.5,1.212869374,176.6675729,0.04037699,163.1387368,164.8486523,167.4742452,171.8421019,176.6675729,181.4651449,185.7601205,188.3203841,189.9791351
1,231.5,1.20574431,176.6906844,0.040371962,163.1655866,164.8745955,167.4990462,171.8656596,176.6906844,181.4887473,185.7849287,188.3462469,190.0058126
1,232.5,1.199251356,176.712721,0.040368149,163.1906925,164.8989187,167.5223947,171.8879838,176.712721,181.5113488,185.8087343,188.3710763,190.0314253
1,233.5,1.19335477,176.733743,0.040365456,163.2141625,164.9217215,167.5443789,171.9091473,176.733743,181.5330026,185.8315877,188.394923,190.0560245
1,234.5,1.188019859,176.753807,0.040363795,163.2360985,164.9430978,167.5650814,171.9292179,176.753807,181.5537583,185.8535364,188.4178347,190.0796588
1,235.5,1.183213059,176.7729657,0.04036308,163.2565964,164.9631357,167.5845802,171.9482593,176.7729657,181.5736625,185.874625,188.4398562,190.1023738
1,236.5,1.178901998,176.7912687,0.040363233,163.2757461,164.9819181,167.602948,171.9663314,176.7912687,181.5927588,185.8948951,188.4610297,190.1242124
1,237.5,1.175055543,176.8087622,0.040364179,163.2936325,164.9995229,167.6202536,171.9834901,176.8087622,181.6110879,185.914386,188.481395,190.1452154
1,238.5,1.171643828,176.8254895,0.04036585,163.3103353,165.0160233,167.6365611,171.9997878,176.8254895,181.6286882,185.9331347,188.5009894,190.1654212
1,239.5,1.16863827,176.8414914,0.04036818,163.3259293,165.031488,167.6519311,172.0152737,176.8414914,181.6455954,185.9511757,188.5198484,190.1848658
1,240,1.167279219,176.8492322,0.040369574,163.3333326,165.0388523,167.6592824,172.0227268,176.8492322,181.6537998,185.9599411,188.5290125,190.1943135
2,24,1.07244896,84.97555512,0.040791394,78.43754166,79.25981989,80.52476467,82.63523563,84.97555512,87.31121356,89.40951159,90.66354871,91.47728689
2,24.5,1.051272912,85.3973169,0.040859727,78.82133263,79.64776859,80.91946302,83.04213246,85.3973169,87.74917522,89.86315834,91.12706971,91.94741225
2,25.5,1.041951175,86.29026318,0.041142161,79.60197647,80.44225735,81.73540957,83.89430336,86.29026318,88.683435,90.83504785,92.12167631,92.95684975
2,26.5,1.012592236,87.15714182,0.041349399,80.37554759,81.22666181,82.5369944,84.72592034,87.15714182,89.5875095,91.77420584,93.08254082,93.9320912
2,27.5,0.970541909,87.9960184,0.041500428,81.1356973,81.99539596,83.31968453,85.53389245,87.9960184,90.46017565,92.67968776,94.00872819,94.87214661
2,28.5,0.921129988,88.8055115,0.041610508,81.87746051,82.74410888,84.07997909,86.31588888,88.8055115,91.30065173,93.55096822,94.89974364,95.77649339
2,29.5,0.868221392,89.58476689,0.041691761,82.59711819,83.46956585,84.81531679,87.07028387,89.58476689,92.10858598,94.38792816,95.75551171,96.64504712
2,30.5,0.81454413,90.33341722,0.04175368,83.29206184,84.16952943,85.52398013,87.7960919,90.33341722,92.88403041,95.19083262,96.57635253,97.47813528
2,31.5,0.761957977,91.0515436,0.041803562,83.96065415,84.84263937,86.20500071,88.49290603,91.0515436,93.62741325,95.96030359,97.36295103,98.27646264
2,32.5,0.711660228,91.7396352,0.041846882,84.60209562,85.48829708,86.85806752,89.16083624,91.7396352,94.33950841,96.69728978,98.11632342,99.04107435
2,33.5,0.664323379,92.39854429,0.041887626,85.21630353,86.10655881,87.48343922,89.80044644,92.39854429,95.02140026,97.40303421,98.83778417,99.77332166
2,34.5,0.620285102,93.02945392,0.041928568,85.80378996,86.69803144,88.08186325,90.41270297,93.02945392,95.67445723,98.07904266,99.52890698,100.4748164
2,35.5,0.57955631,93.63382278,0.041971514,86.36557262,87.26378819,88.6544988,90.99890839,93.63382278,96.30028751,98.72704954,100.191497,101.1474075
2,36.5,0.54198094,94.21335709,0.042017509,86.90307328,87.80528157,89.20284893,91.56065781,94.21335709,96.9007148,99.34898744,100.8275527,101.7931359
2,37.5,0.511429832,94.79643239,0.042104522,87.43482018,88.34236213,89.74875322,92.12298263,94.79643239,97.50723533,99.97896123,101.4726459,102.448488
2,38.5,0.482799937,95.37391918,0.042199507,87.95945137,88.87255864,90.28810699,92.67925322,95.37391918,98.10854769,100.6040005,102.112939,103.0991159
2,39.5,0.455521041,95.94692677,0.042300333,88.47849954,89.39733426,90.82227549,93.23069622,95.94692677,98.70568284,101.2250993,102.7494191,103.7460086
2,40.5,0.429150288,96.51644912,0.042405225,88.99330218,89.91797078,91.35246174,93.77840211,96.51644912,99.2995686,101.8431523,103.3829734,104.3900531
2,41.5,0.403351725,97.08337211,0.042512706,89.50502066,90.43558554,91.87972051,94.3233355,97.08337211,99.89103539,102.4589604,104.0143944,105.0320405
2,42.5,0.377878239,97.6484807,0.042621565,90.01465759,90.95114701,92.40497144,94.86634477,97.6484807,100.4808219,103.0732359,104.6443859,105.6726719
2,43.5,0.352555862,98.21246579,0.042730809,90.52307278,91.4654891,92.92901112,95.40817129,98.21246579,101.0695807,103.6866076,105.2735676,106.3125633
2,44.5,0.327270297,98.77593069,0.042839638,91.03099757,91.97932415,93.45252422,95.94945793,98.77593069,101.6578832,104.2996257,105.9024803,106.9522508
2,45.5,0.301955463,99.33939735,0.042947412,91.5390479,92.49325483,93.97609374,96.49075704,99.33939735,102.2462253,104.9127666,106.5315907,107.5921959
2,46.5,0.276583851,99.9033122,0.043053626,92.04773605,93.00778484,94.50021028,97.03253788,99.9033122,102.8350319,105.5264371,107.161296,108.2327896
2,47.5,0.251158446,100.4680516,0.043157889,92.55748123,93.52332863,95.02528063,97.57519341,100.4680516,103.4246616,106.1409795,107.7919282,108.8743573
2,48.5,0.225705996,101.033927,0.043259907,93.06861913,94.04022021,95.55163545,98.11904662,101.033927,104.0154114,106.7566748,108.4237579,109.5171624
2,49.5,0.20027145,101.6011898,0.043359463,93.58141046,94.55872109,96.07953634,98.66435637,101.6011898,104.6075204,107.3737475,109.0569988,110.1614111
2,50.5,0.174913356,102.1700358,0.043456406,94.09604867,95.07902737,96.60918226,99.2113227,102.1700358,105.2011743,107.9923687,109.6918111,110.8072554
2,51.5,0.149700081,102.7406094,0.043550638,94.61266684,95.60127628,97.14071535,99.76009185,102.7406094,105.7965086,108.6126601,110.3283052,111.4547971
2,52.5,0.12470671,103.3130077,0.043642107,95.13134395,96.12555202,97.67422621,100.3107608,103.3130077,106.3936129,109.2346972,110.9665451,112.1040915
2,53.5,0.100012514,103.8872839,0.043730791,95.65211042,96.65189097,98.20975881,100.8633813,103.8872839,106.9925336,109.8585126,111.6065515,112.7551501
2,54.5,0.075698881,104.4634511,0.043816701,96.17495324,97.18028656,98.74731484,101.4179641,104.4634511,107.5932772,110.4840992,112.2483051,113.4079442
2,55.5,0.051847635,105.0414853,0.043899867,96.69982047,97.7106936,99.28685775,101.9744822,105.0414853,108.1958137,111.1114131,112.8917498,114.0624076
2,56.5,0.02853967,105.6213287,0.043980337,97.2266254,98.24303219,99.82831652,102.5328747,105.6213287,108.8000793,111.7403765,113.536795,114.7184401
2,57.5,0.005853853,106.2028921,0.044058171,97.75525036,98.77719141,100.371589,103.0930492,106.2028921,109.405979,112.3708801,114.1833188,115.3759096
2,58.5,-0.016133871,106.7860583,0.04413344,98.28555005,99.31303257,100.9165451,103.6548853,106.7860583,110.0133894,113.0027865,114.8311708,116.0346553
2,59.5,-0.037351181,107.3706841,0.044206218,98.81735475,99.85039229,101.4630296,104.2182371,107.3706841,110.6221611,113.6359317,115.4801741,116.6944901
2,60.5,-0.057729947,107.9566031,0.044276588,99.35047319,100.3890853,102.0108651,104.7829358,107.9566031,111.2321213,114.2701285,116.1301284,117.3552032
2,61.5,-0.077206672,108.5436278,0.044344632,99.88469514,100.9289069,102.5598541,105.348792,108.5436278,111.8430758,114.9051683,116.780812,118.0165629
2,62.5,-0.09572283,109.1315521,0.044410436,100.4197939,101.4696357,103.1097819,105.9155982,109.1315521,112.4548114,115.5408235,117.4319846,118.6783183
2,63.5,-0.113225128,109.7201531,0.044474084,100.9555286,102.0110354,103.6604184,106.4831306,109.7201531,113.0670984,116.1768496,118.0833889,119.3402023
2,64.5,-0.129665689,110.3091934,0.044535662,101.4916463,102.5528574,104.2115203,107.0511517,110.3091934,113.6796918,116.8129879,118.7347537,120.0019338
2,65.5,-0.145002179,110.8984228,0.044595254,102.0278838,103.0948423,104.762833,107.6194116,110.8984228,114.2923342,117.4489667,119.3857953,120.6632194
2,66.5,-0.159197885,111.4875806,0.044652942,102.5639698,103.6367221,105.3140925,108.1876502,111.4875806,114.9047572,118.0845041,120.03622,121.3237564
2,67.5,-0.172221748,112.0763967,0.044708809,103.0996264,104.1782217,105.8650274,108.7555991,112.0763967,115.5166834,118.7193096,120.685726,121.9832342
2,68.5,-0.184048358,112.6645943,0.044762936,103.6345709,104.7190606,106.4153599,109.3229831,112.6645943,116.1278283,119.3530862,121.3340057,122.6413368
2,69.5,-0.194660215,113.2518902,0.044815402,104.1685175,105.258955,106.9648081,109.8895213,113.2518902,116.7379017,119.9855318,121.9807474,123.297745
2,70.5,-0.204030559,113.8380006,0.044866288,104.7011761,105.797617,107.5130874,110.4549317,113.8380006,117.3466121,120.6163423,122.6256361,123.9521353
2,71.5,-0.212174408,114.4226317,0.044915672,105.2322625,106.3347618,108.0599112,111.0189247,114.4226317,117.9536599,121.2452109,123.2683596,124.6041916
2,72.5,-0.219069129,115.0054978,0.044963636,105.7614857,106.8701003,108.6049935,111.5812164,115.0054978,118.5587525,121.8718331,123.9086035,125.2535916
2,73.5,-0.224722166,115.5863089,0.045010259,106.2885612,107.4033481,109.148049,112.1415202,115.5863089,119.1615941,122.4959057,124.5460585,125.9000218
2,74.5,-0.229140412,116.1647782,0.045055624,106.8132066,107.9342229,109.6887954,112.6995522,116.1647782,119.7618926,123.1171295,125.1804203,126.5431735
2,75.5,-0.232335686,116.7406221,0.045099817,107.3351443,108.4624465,110.2269537,113.2550319,116.7406221,120.3593603,123.7352109,125.8113907,127.1827453
2,76.5,-0.234324563,117.3135622,0.045142924,107.8541019,108.987746,110.7622502,113.8076835,117.3135622,120.9537147,124.3498634,126.4386798,127.8184451
2,77.5,-0.235128195,117.8833259,0.045185036,108.3698135,109.5098548,111.2944168,114.3572371,117.8833259,121.5446807,124.9608087,127.0620077,128.4499914
2,78.5,-0.234772114,118.4496481,0.045226249,108.8820206,110.0285133,111.8231928,114.9034294,118.4496481,122.1319914,125.5677788,127.6811055,129.0771148
2,79.5,-0.233286033,119.0122722,0.045266662,109.3904733,110.5434704,112.3483251,115.4460056,119.0122722,122.7153896,126.1705167,128.2957169,129.69956
2,80.5,-0.230703633,119.5709513,0.045306383,109.8949308,111.0544841,112.8695701,115.9847196,119.5709513,123.2946291,126.7687784,128.9056,130.3170863
2,81.5,-0.227062344,120.1254495,0.045345524,110.3951624,111.5613221,113.3866939,116.5193358,120.1254495,123.8694758,127.3623338,129.5105281,130.9294701
2,82.5,-0.222403111,120.6755427,0.045384203,110.890948,112.0637632,113.8994733,117.0496296,120.6755427,124.4397092,127.9509681,130.1102914,131.5365053
2,83.5,-0.216770161,121.22102,0.045422551,111.3820796,112.5615976,114.407697,117.5753884,121.22102,125.0051231,128.5344832,130.7046982,132.1380052
2,84.5,-0.210210748,121.7616844,0.045460702,111.868361,113.054628,114.9111662,118.0964128,121.7616844,125.5655273,129.1126986,131.2935761,132.7338033
2,85.5,-0.202774891,122.2973542,0.045498803,112.3496093,113.54267,115.4096953,118.6125173,122.2973542,126.1207484,129.6854529,131.876773,133.323755
2,86.5,-0.194515104,122.827864,0.045537012,112.825655,114.0255532,115.9031127,119.1235313,122.827864,126.6706308,130.2526047,132.4541587,133.9077383
2,87.5,-0.185486099,123.3530652,0.045575495,113.2963432,114.5031216,116.391262,119.6293,123.3530652,127.2150383,130.8140342,133.025626,134.4856552
2,88.5,-0.175744476,123.8728276,0.045614432,113.7615336,114.9752341,116.874002,120.1296849,123.8728276,127.7538545,131.3696436,133.5910912,135.0574328
2,89.5,-0.165348396,124.38704,0.045654016,114.2211014,115.4417656,117.351208,120.6245654,124.38704,128.2869845,131.9193587,134.150496,135.6230245
2,90.5,-0.15435722,124.8956114,0.04569445,114.674938,115.9026074,117.8227724,121.113839,124.8956114,128.8143555,132.4631302,134.7038082,136.1824107
2,91.5,-0.142831123,125.398472,0.045735953,115.1229513,116.3576679,118.2886054,121.5974226,125.398472,129.3359181,133.000934,135.2510227,136.7356
2,92.5,-0.130830669,125.895574,0.045778759,115.5650666,116.8068731,118.7486357,122.0752529,125.895574,129.8516474,133.5327731,135.7921628,137.2826306
2,93.5,-0.118416354,126.3868929,0.045823114,116.001227,117.2501678,119.2028114,122.5472882,126.3868929,130.3615441,134.0586782,136.3272809,137.8235707
2,94.5,-0.105648092,126.8724284,0.04586928,116.4313942,117.6875155,119.651101,123.0135084,126.8724284,130.8656354,134.5787089,136.8564598,138.3585197
2,95.5,-0.092584657,127.3522056,0.045917535,116.8555488,118.1188998,120.0934937,123.4739166,127.3522056,131.3639763,135.0929548,137.3798137,138.8876092
2,96.5,-0.079283065,127.8262759,0.045968169,117.2736916,118.5443251,120.5300007,123.92854,127.8262759,131.8566506,135.6015364,137.8974887,139.411004
2,97.5,-0.065797888,128.2947187,0.04602149,117.6858437,118.9638171,120.9606563,124.3774309,128.2947187,132.3437724,136.1046066,138.4096645,139.9289024
2,98.5,-0.0521805,128.757642,0.046077818,118.092048,119.3774239,121.3855185,124.8206679,128.757642,132.8254867,136.602351,138.9165546,140.4415378
2,99.5,-0.03847825,129.2151839,0.046137487,118.4923693,119.7852171,121.8046703,125.2583572,129.2151839,133.3019713,137.0949894,139.4184075,140.9491785
2,100.5,-0.024733545,129.6675143,0.046200842,118.8868959,120.1872927,122.2182208,125.6906338,129.6675143,133.7734371,137.5827768,139.9155075,141.4521292
2,101.5,-0.010982868,130.1148354,0.04626824,119.2757403,120.5837721,122.6263066,126.1176628,130.1148354,134.2401302,138.0660041,140.4081749,141.9507308
2,102.5,0.002744306,130.5573839,0.046340046,119.6590402,120.9748035,123.029093,126.5396411,130.5573839,134.7023324,138.5449986,140.8967672,142.4453609
2,103.5,0.016426655,130.995432,0.046416629,120.0369603,121.3605632,123.4267753,126.9567984,130.995432,135.1603626,139.0201256,141.3816789,142.936434
2,104.5,0.030052231,131.4292887,0.046498361,120.4096928,121.7412571,123.8195805,127.3693994,131.4292887,135.6145777,139.4917879,141.8633417,143.4244013
2,105.5,0.043619747,131.8593015,0.046585611,120.7774598,122.1171219,124.2077692,127.7777448,131.8593015,136.0653737,139.9604267,142.3422248,143.9097502
2,106.5,0.05713988,132.2858574,0.046678741,121.140514,122.4884272,124.5916364,128.1821733,132.2858574,136.5131864,140.4265216,142.818834,144.3930034
2,107.5,0.070636605,132.7093845,0.046778099,121.4991408,122.8554769,124.9715143,128.5830629,132.7093845,136.9584917,140.8905903,143.2937108,144.8747179
2,108.5,0.08414848,133.1303527,0.04688401,121.8536605,123.2186111,125.3477734,128.9808329,133.1303527,137.4018066,141.3531879,143.7674316,145.3554829
2,109.5,0.097729873,133.5492749,0.046996769,122.2044292,123.5782083,125.7208245,129.3759451,133.5492749,137.8436884,141.8149059,144.2406053,145.8359173
2,110.5,0.111452039,133.9667073,0.047116633,122.551842,123.9346869,126.0911208,129.7689053,133.9667073,138.2847346,142.2763706,144.7138712,146.3166671
2,111.5,0.125404005,134.3832499,0.047243801,122.8963342,124.2885075,126.4591593,130.1602643,134.3832499,138.7255822,142.7382405,145.1878952,146.798401
2,112.5,0.13969316,134.7995463,0.047378413,123.2383839,124.6401749,126.8254825,130.5506193,134.7995463,139.1669053,143.2012034,145.6633664,147.2818057
2,113.5,0.154445482,135.2162826,0.047520521,123.5785142,124.9902397,127.1906801,130.9406135,135.2162826,139.6094137,143.6659721,146.1409913,147.7675803
2,114.5,0.169805275,135.634186,0.047670085,123.9172948,125.3393004,127.5553896,131.330937,135.634186,140.0538485,144.1332799,146.6214882,148.2564292
2,115.5,0.185934346,136.0540223,0.047826946,124.2553446,125.6880049,127.9202978,131.7223254,136.0540223,140.5009788,144.6038739,147.1055797,148.7490543
2,116.5,0.203010488,136.4765925,0.04799081,124.5933332,126.0370512,128.2861404,132.1155587,136.4765925,140.9515953,145.0785079,147.5939843,149.2461456
2,117.5,0.2212252,136.9027281,0.048161228,124.9319822,126.3871885,128.6537014,132.5114586,136.9027281,141.406504,145.5579335,148.0874065,149.7483713
2,118.5,0.240780542,137.3332846,0.04833757,125.2720662,126.7392174,129.0238124,132.9108849,137.3332846,141.8665172,146.0428902,148.586526,150.2563656
2,119.5,0.261885086,137.7691339,0.048519011,125.6144133,127.0939883,129.3973496,133.3147302,137.7691339,142.3324443,146.5340936,149.0919854,150.7707169
2,120.5,0.284748919,138.2111552,0.048704503,125.9599043,127.4524005,129.7752299,133.7239135,138.2111552,142.8050794,147.0322225,149.6043767,151.2919534
2,121.5,0.309577733,138.6602228,0.048892759,126.3094709,127.8153983,130.1584061,134.1393714,138.6602228,143.2851879,147.5379045,150.1242269,151.8205297
2,122.5,0.336566048,139.1171933,0.049082239,126.6640931,128.1839668,130.5478595,134.5620476,139.1171933,143.7734919,148.0517004,150.6519828,152.3568114
2,123.5,0.365889711,139.5828898,0.049271137,127.0247941,128.5591249,130.9445907,134.9928804,139.5828898,144.2706527,148.5740881,151.1879951,152.9010603
2,124.5,0.397699038,140.0580848,0.049457371,127.3926332,128.9419168,131.3496084,135.4327874,140.0580848,144.7772534,149.1054445,151.7325029,153.4534201
2,125.5,0.432104409,140.5434787,0.049638596,127.7686986,129.3334014,131.7639151,135.8826474,140.5434787,145.2937779,149.6460289,152.2856189,154.0139039
2,126.5,0.46917993,141.0396832,0.049812203,128.1540923,129.7346372,132.1884911,136.3432832,141.0396832,145.8205935,150.1959657,152.8473131,154.5823786
2,127.5,0.508943272,141.5471945,0.049975355,128.5499184,130.1466666,132.6242751,136.8154369,141.5471945,146.3579283,150.7552278,153.4174019,155.1585578
2,128.5,0.551354277,142.0663731,0.050125012,128.9572634,130.5704957,133.072142,137.299748,142.0663731,146.9058529,151.3236226,153.9955367,155.741993
2,129.5,0.596307363,142.59742,0.050257992,129.3771753,131.0070717,133.5328789,137.7967284,142.59742,147.4642617,151.9007796,154.581196,156.3320686
2,130.5,0.643626542,143.1403553,0.050371024,129.8106385,131.4572565,134.0071586,138.3067365,143.1403553,148.0328573,152.4861414,155.1736815,156.9280012
2,131.5,0.693062173,143.6949981,0.050460835,130.2585454,131.9217986,134.4955119,138.8299523,143.6949981,148.6111378,153.0789588,155.7721177,157.5288429
2,132.5,0.744289752,144.2609497,0.050524236,130.7216652,132.4013028,134.9982982,139.3663536,144.2609497,149.1983881,153.6782905,156.3754566,158.1334886
2,133.5,0.79691098,144.8375809,0.050558224,131.2006102,132.8961979,135.5156778,139.9156938,144.8375809,149.7936767,154.2830074,156.9824866,158.740688
2,134.5,0.85045728,145.4240246,0.050560083,131.6958014,133.4067049,136.0475846,140.4774848,145.4240246,150.3958583,154.8918033,157.591847,159.3490618
2,135.5,0.904395871,146.0191748,0.050527494,132.2074327,133.9328066,136.5937022,141.0509836,146.0191748,151.0035823,155.5032105,158.2020466,159.9571223
2,136.5,0.958138449,146.621692,0.050458634,132.7354383,134.4742195,137.1534445,141.6351863,146.621692,151.6153083,156.1156207,158.8114866,160.5632969
2,137.5,1.011054559,147.2300177,0.050352269,133.2794613,135.0303699,137.7259419,142.228829,147.2300177,152.2293288,156.7273114,159.4184879,161.1659545
2,138.5,1.062474568,147.8423918,0.050207825,133.8388331,135.6003795,138.3100351,142.8303943,147.8423918,152.8437944,157.336476,160.0213216,161.7634371
2,139.5,1.111727029,148.4568879,0.050025434,134.4125492,136.1830524,138.9042785,143.4381342,148.4568879,153.4567526,157.9412574,160.6182378,162.3540831
2,140.5,1.158135105,149.0714413,0.049805967,134.9992687,136.7768804,139.5069517,144.0500909,149.0714413,154.0661803,158.5397832,161.2075007,162.9362629
2,141.5,1.201050821,149.6838943,0.049551023,135.5973139,137.3800519,140.1160824,144.6641345,149.6838943,154.6700274,159.1302018,161.7874182,163.5084028
2,142.5,1.239852328,150.2920328,0.049262895,136.2046931,137.9904798,140.7294775,145.2779986,150.2920328,155.2662534,159.710717,162.3563754,164.0690181
2,143.5,1.274006058,150.8936469,0.048944504,136.8191174,138.6058289,141.3447662,145.8893375,150.8936469,155.8528786,160.2796226,162.9128551,164.6167234
2,144.5,1.303044695,151.4865636,0.048599314,137.4380555,139.2235689,141.9594471,146.4957662,151.4865636,156.4280126,160.8353311,163.4554684,165.1502647
2,145.5,1.326605954,152.0686985,0.048231224,138.0587804,139.8410247,142.5709442,147.0949169,152.0686985,156.9898953,161.3763995,163.9829705,165.6685285
2,146.5,1.344443447,152.6380955,0.047844442,138.6784334,140.4554388,143.1766639,147.6844892,152.6380955,157.5369262,161.9015501,164.4942764,166.1705539
2,147.5,1.356437773,153.1929631,0.047443362,139.2940935,141.064036,143.7740547,148.2622979,153.1929631,158.0676887,162.4096857,164.9884705,166.6555396
2,148.5,1.362602695,153.7317031,0.04703243,139.902849,141.6640898,144.3606631,148.8263158,153.7317031,158.5809683,162.8998985,165.4648118,167.1228459
2,149.5,1.363085725,154.2529332,0.046616026,140.5018697,142.2529855,144.9341866,149.3747099,154.2529332,159.0757636,163.3714746,165.9227345,167.5719943
2,150.5,1.358162799,154.755501,0.046198356,141.0884738,142.8282787,145.4925187,149.9058698,154.755501,159.5512908,163.8238923,166.3618445,168.0026622
2,151.5,1.348227142,155.2384904,0.04578335,141.6601883,143.3877452,146.0337866,150.4184277,155.2384904,160.006982,164.2568163,166.7819123,168.4146759
2,152.5,1.333772923,155.7012216,0.045374597,142.2147984,143.9294218,146.5563788,150.9112703,155.7012216,160.4424774,164.6700879,167.1828627,168.8080012
2,153.5,1.315374704,156.1432438,0.044975281,142.7503859,144.4516354,147.0589626,151.3835413,156.1432438,160.8576139,165.0637118,167.5647631,169.1827317
2,154.5,1.293664024,156.564323,0.044588148,143.2653544,144.9530205,147.5404925,151.8346381,156.564323,161.252409,165.4378408,167.9278093,169.5390766
2,155.5,1.269304678,156.9644258,0.044215488,143.7584411,145.4325259,148.0002085,152.2642007,156.9644258,161.6270427,165.7927589,168.2723104,169.8773471
2,156.5,1.242968236,157.3436995,0.043859135,144.2287179,145.8894106,148.437627,152.6720956,157.3436995,161.9818377,166.1288638,168.5986736,170.1979436
2,157.5,1.21531127,157.7024507,0.04352048,144.6755805,146.3232308,148.8525242,153.0583966,157.7024507,162.317239,166.4466488,168.9073892,170.5013414
2,158.5,1.186955477,158.0411233,0.043200497,145.0987292,146.7338197,149.2449147,153.4233611,158.0411233,162.633793,166.7466859,169.1990151,170.7880784
2,159.5,1.158471522,158.3602756,0.042899776,145.4981426,147.1212613,149.6150259,153.7674066,158.3602756,162.9321282,167.0296087,169.474163,171.0587419
2,160.5,1.130367088,158.6605588,0.042618565,145.8740473,147.4858611,149.9632704,154.0910856,158.6605588,163.2129368,167.2960978,169.7334849,171.3139575
2,161.5,1.103079209,158.9426964,0.042356812,146.2268836,147.8281145,150.2902174,154.3950608,158.9426964,163.476957,167.5468664,169.9776618,171.5543778
2,162.5,1.076970655,159.2074654,0.042114211,146.5572714,148.148675,150.5965645,154.6800825,159.2074654,163.7249588,167.7826481,170.207392,171.780673
2,163.5,1.052329922,159.455679,0.041890247,146.8659759,148.4483225,150.8831097,154.9469659,159.455679,163.9577297,168.0041861,170.4233822,171.9935219
2,164.5,1.029374161,159.688172,0.04168424,147.1538752,148.7279342,151.1507267,155.1965718,159.688172,164.1760637,168.2122241,170.6263392,172.1936047
2,165.5,1.008254396,159.9057871,0.041495379,147.4219304,148.9884574,151.4003414,155.4297888,159.9057871,164.3807514,168.4074983,170.8169629,172.3815959
2,166.5,0.989062282,160.1093647,0.041322765,147.6711585,149.2308852,151.6329115,155.6475179,160.1093647,164.572572,168.5907313,170.9959407,172.5581591
2,167.5,0.971837799,160.299733,0.041165437,147.902609,149.4562355,151.8494087,155.8506598,160.299733,164.7522868,168.7626268,171.1639423,172.7239426
2,168.5,0.95657215,160.4776996,0.041022401,148.1173446,149.6655332,152.0508033,156.0401024,160.4776996,164.920633,168.9238654,171.3216174,172.8795764
2,169.5,0.94324228,160.6440526,0.040892651,148.3164186,149.8597926,152.238053,156.2167175,160.6440526,165.0783248,169.0751026,171.469589,173.0256638
2,170.5,0.931767062,160.7995428,0.040775193,148.5008727,150.0400107,152.4120911,156.3813442,160.7995428,165.2260411,169.2169651,171.6084579,173.1627906
2,171.5,0.922058291,160.9448916,0.040669052,148.6717163,150.2071532,152.5738202,156.5347914,160.9448916,165.3644316,169.3500504,171.7387957,173.2915138
2,172.5,0.914012643,161.0807857,0.040573288,148.8299213,150.3621482,152.7241057,156.6778321,161.0807857,165.4941133,169.4749261,171.8611461,173.4123635
2,173.5,0.907516917,161.2078755,0.040487005,148.976416,150.5058813,152.8637721,156.8112003,161.2078755,165.6156697,169.5921291,171.9760242,173.5258431
2,174.5,0.902452436,161.3267744,0.040409354,149.1120814,150.6391923,152.9936001,156.9355896,161.3267744,165.7296508,169.7021662,172.0839168,173.6324287
2,175.5,0.898698641,161.4380593,0.040339537,149.2377485,150.7628729,153.1143251,157.0516529,161.4380593,165.8365737,169.8055142,172.1852824,173.7325694
2,176.5,0.896143482,161.5422726,0.040276811,149.3541954,150.877665,153.2266371,157.1600033,161.5422726,165.9369248,169.9026209,172.2805514,173.8266863
2,177.5,0.894659668,161.639917,0.040220488,149.4621532,150.9842639,153.3311804,157.2612106,161.639917,166.0311556,169.9939056,172.3701297,173.9151788
2,178.5,0.89413892,161.7314645,0.040169932,149.5622993,151.0833153,153.4285552,157.3558081,161.7314645,166.1196904,170.0797608,172.4543957,173.9984185
2,179.5,0.894475371,161.8173534,0.040124562,149.6552628,151.1754186,153.5193185,157.4442908,161.8173534,166.202924,170.160553,172.5337038,174.0767538
2,180.5,0.895569834,161.8979913,0.040083845,149.7416255,151.2611287,153.6039864,157.5271178,161.8979913,166.281224,170.236624,172.6083849,174.1505102
2,181.5,0.897330209,161.9737558,0.040047295,149.8219242,151.3409575,153.6830356,157.6047139,161.9737558,166.3549321,170.3082921,172.6787478,174.2199918
2,182.5,0.899671635,162.0449969,0.040014473,149.8966533,151.415377,153.7569057,157.6774719,162.0449969,166.4243655,170.3758539,172.7450799,174.2854819
2,183.5,0.902516442,162.1120386,0.03998498,149.9662668,151.4848208,153.8260015,157.7457539,162.1120386,166.4898188,170.4395847,172.8076491,174.3472447
2,184.5,0.905793969,162.17518,0.039958458,150.0311812,151.5496874,153.8906954,157.809894,162.17518,166.5515647,170.4997408,172.8667045,174.405526
2,185.5,0.909440266,162.2346979,0.039934584,150.0917784,151.610342,153.951329,157.8701998,162.2346979,166.6098562,170.5565599,172.9224777,174.4605545
2,186.5,0.913397733,162.2908474,0.039913066,150.1484074,151.6671193,154.0082162,157.9269542,162.2908474,166.6649274,170.6102627,172.9751838,174.5125428
2,187.5,0.91761471,162.343864,0.039893644,150.2013879,151.7203255,154.0616446,157.9804176,162.343864,166.7169951,170.6610542,173.025023,174.5616886
2,188.5,0.922045055,162.3939652,0.039876087,150.2510113,151.7702407,154.1118775,158.0308292,162.3939652,166.7662599,170.7091243,173.0721808,174.6081757
2,189.5,0.926647697,162.4413513,0.039860185,150.2975443,151.8171212,154.1591564,158.0784088,162.4413513,166.8129074,170.7546494,173.1168298,174.6521747
2,190.5,0.931386217,162.4862071,0.039845754,150.3412298,151.8612008,154.2037023,158.1233583,162.4862071,166.8571093,170.7977929,173.1591301,174.6938442
2,191.5,0.93622842,162.5287029,0.039832629,150.3822898,151.9026934,154.2457175,158.1658633,162.5287029,166.8990246,170.8387064,173.1992303,174.7333314
2,192.5,0.941145943,162.5689958,0.039820663,150.4209266,151.9417942,154.2853872,158.2060942,162.5689958,166.9388003,170.8775306,173.2372685,174.7707732
2,193.5,0.94611388,162.6072309,0.039809725,150.4573249,151.9786817,154.3228809,158.2442076,162.6072309,166.9765723,170.914396,173.2733728,174.8062967
2,194.5,0.95111043,162.6435418,0.0397997,150.4916531,152.013519,154.3583538,158.2803474,162.6435418,167.0124668,170.9494236,173.3076624,174.8400201
2,195.5,0.956116576,162.6780519,0.039790485,150.524065,152.0464549,154.3919483,158.3146459,162.6780519,167.0466004,170.9827258,173.3402478,174.8720532
2,196.5,0.961115792,162.7108751,0.039781991,150.5547008,152.0776257,154.4237944,158.3472249,162.7108751,167.0790811,171.014407,173.3712319,174.902498
2,197.5,0.966093766,162.7421168,0.039774136,150.5836887,152.1071558,154.4540118,158.3781962,162.7421168,167.110009,171.0445641,173.4007102,174.9314494
2,198.5,0.971038162,162.7718741,0.03976685,150.6111457,152.1351593,154.4827098,158.407663,162.7718741,167.1394771,171.0732871,173.4287717,174.9589959
2,199.5,0.975938391,162.8002371,0.03976007,150.6371789,152.1617405,154.509989,158.4357202,162.8002371,167.1675715,171.1006598,173.455499,174.9852197
2,200.5,0.980785418,162.8272889,0.039753741,150.661886,152.1869949,154.5359417,158.4624554,162.8272889,167.1943721,171.1267599,173.4809691,175.0101973
2,201.5,0.985571579,162.8531067,0.039747815,150.6853568,152.2110102,154.5606528,158.4879492,162.8531067,167.2199532,171.1516601,173.5052538,175.034
2,202.5,0.99029042,162.8777619,0.039742249,150.7076733,152.2338667,154.5842002,158.5122763,162.8777619,167.244384,171.1754277,173.5284198,175.0566944
2,203.5,0.994936555,162.9013208,0.039737004,150.7289106,152.2556383,154.6066558,158.5355056,162.9013208,167.2677286,171.1981258,173.5505296,175.0783424
2,204.5,0.999505539,162.9238449,0.039732048,150.749138,152.2763929,154.6280858,158.5577008,162.9238449,167.2900467,171.2198128,173.5716411,175.099002
2,205.5,1.003993753,162.9453912,0.039727352,150.7684187,152.296193,154.6485512,158.578921,162.9453912,167.3113942,171.2405436,173.5918087,175.1187272
2,206.5,1.0083983,162.9660131,0.03972289,150.7868111,152.3150959,154.6681084,158.5992207,162.9660131,167.3318229,171.2603693,173.6110831,175.1375685
2,207.5,1.012716921,162.9857599,0.03971864,150.8043689,152.3331548,154.6868095,158.6186507,162.9857599,167.3513812,171.2793375,173.6295117,175.155573
2,208.5,1.016947912,163.0046776,0.039714581,150.8211416,152.3504187,154.7047027,158.6372582,163.0046776,167.3701145,171.2974929,173.6471389,175.1727851
2,209.5,1.021090055,163.0228094,0.039710697,150.8371748,152.3669327,154.7218327,158.6550869,163.0228094,167.388065,171.3148774,173.6640061,175.1892459
2,210.5,1.025142554,163.0401953,0.039706971,150.8525106,152.3827387,154.7382408,158.6721776,163.0401953,167.4052723,171.33153,173.6801522,175.2049944
2,211.5,1.029104983,163.0568727,0.039703391,150.8671882,152.3978755,154.7539655,158.6885682,163.0568727,167.4217734,171.3474874,173.6956138,175.2200667
2,212.5,1.032977233,163.0728768,0.039699945,150.8812435,152.412379,154.7690427,158.7042942,163.0728768,167.437603,171.362784,173.710425,175.2344971
2,213.5,1.036759475,163.0882404,0.039696623,150.8947102,152.4262827,154.7835054,158.7193886,163.0882404,167.4527938,171.3774521,173.7246179,175.2483174
2,214.5,1.040452117,163.1029943,0.039693415,150.9076191,152.4396177,154.7973849,158.7338824,163.1029943,167.4673763,171.3915221,173.7382228,175.2615577
2,215.5,1.044055774,163.1171673,0.039690313,150.9199994,152.4524128,154.81071,158.7478045,163.1171673,167.4813792,171.4050225,173.751268,175.2742464
2,216.5,1.047571238,163.1307866,0.039687311,150.9318778,152.464695,154.8235077,158.7611821,163.1307866,167.4948296,171.4179802,173.7637802,175.2864101
2,217.5,1.050999451,163.1438776,0.039684402,150.9432795,152.4764895,154.8358035,158.7740404,163.1438776,167.5077529,171.4304205,173.7757847,175.2980736
2,218.5,1.054341482,163.1564644,0.039681581,150.9542279,152.4878198,154.8476208,158.7864036,163.1564644,167.520173,171.4423671,173.787305,175.3092608
2,219.5,1.057598512,163.1685697,0.039678842,150.9647448,152.498708,154.8589821,158.798294,163.1685697,167.5321128,171.4538427,173.7983636,175.3199938
2,220.5,1.060771808,163.1802146,0.039676182,150.9748507,152.5091747,154.8699082,158.8097328,163.1802146,167.5435933,171.4648684,173.8089816,175.3302936
2,221.5,1.063862715,163.1914194,0.039673596,150.9845649,152.5192393,154.8804186,158.8207399,163.1914194,167.554635,171.4754644,173.8191789,175.3401801
2,222.5,1.066872639,163.202203,0.039671082,150.9939053,152.52892,154.8905318,158.8313341,163.202203,167.5652567,171.4856495,173.8289744,175.349672
2,223.5,1.069803036,163.2125835,0.039668635,151.0028889,152.5382338,154.9002654,158.8415332,163.2125835,167.5754766,171.4954418,173.8383858,175.358787
2,224.5,1.072655401,163.2225779,0.039666254,151.0115315,152.5471971,154.9096356,158.851354,163.2225779,167.5853118,171.5048583,173.8474302,175.367542
2,225.5,1.075431258,163.2322024,0.039663936,151.0198482,152.5558248,154.9186579,158.8608124,163.2322024,167.5947785,171.5139151,173.8561235,175.3759527
2,226.5,1.078132156,163.2414722,0.039661679,151.0278532,152.5641315,154.9273472,158.8699234,163.2414722,167.6038921,171.5226274,173.8644808,175.3840343
2,227.5,1.080759655,163.2504019,0.039659481,151.0355596,152.5721307,154.9357171,158.8787012,163.2504019,167.6126671,171.5310098,173.8725166,175.391801
2,228.5,1.083315329,163.2590052,0.039657339,151.0429803,152.5798353,154.9437809,158.8871595,163.2590052,167.6211174,171.5390761,173.8802445,175.3992664
2,229.5,1.085800751,163.2672954,0.039655252,151.0501271,152.5872574,154.9515511,158.8953111,163.2672954,167.6292563,171.5468394,173.8876774,175.4064433
2,230.5,1.088217496,163.2752848,0.039653218,151.0570114,152.5944085,154.9590395,158.9031682,163.2752848,167.6370963,171.5543121,173.8948277,175.4133439
2,231.5,1.090567133,163.2829854,0.039651237,151.0636438,152.6012996,154.9662574,158.9107425,163.2829854,167.6446494,171.561506,173.9017071,175.4199799
2,232.5,1.092851222,163.2904086,0.039649306,151.0700346,152.6079412,154.9732154,158.918045,163.2904086,167.6519269,171.5684326,173.9083268,175.4263623
2,233.5,1.095071313,163.297565,0.039647424,151.0761934,152.6143431,154.9799237,158.9250863,163.297565,167.6589397,171.5751024,173.9146973,175.4325015
2,234.5,1.097228939,163.304465,0.039645591,151.0821295,152.6205147,154.9863922,158.9318765,163.304465,167.6656981,171.5815258,173.9208289,175.4384076
2,235.5,1.099325619,163.3111185,0.039643804,151.0878515,152.626465,154.9926299,158.9384252,163.3111185,167.6722121,171.5877126,173.9267311,175.4440902
2,236.5,1.101362852,163.3175349,0.039642063,151.0933679,152.6322026,154.9986458,158.9447416,163.3175349,167.678491,171.5936721,173.9324132,175.4495583
2,237.5,1.103342119,163.3237231,0.039640367,151.0986866,152.6377356,155.0044483,158.9508345,163.3237231,167.684544,171.5994132,173.9378839,175.4548206
2,238.5,1.105264876,163.3296918,0.039638715,151.1038152,152.6430718,155.0100454,158.9567122,163.3296918,167.6903797,171.6049444,173.9431517,175.4598853
2,239.5,1.107132561,163.3354491,0.039637105,151.1087609,152.6482187,155.0154449,158.9623829,163.3354491,167.6960062,171.6102738,173.9482244,175.4647604
2,240,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,241,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,242,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,243,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,244,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,245,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,246,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,247,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,248,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,249,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,250,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,251,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,252,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,253,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,254,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,255,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,256,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,257,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,258,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,259,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,260,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,261,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,262,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,263,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,264,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,265,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,266,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,267,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,268,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,269,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,270,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,271,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,272,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,273,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,274,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,275,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,276,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,277,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,278,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,279,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,280,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,281,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,282,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,283,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,284,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,285,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,286,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,287,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,288,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,289,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,290,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,291,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,292,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,293,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,294,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,295,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,296,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,297,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,298,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,299,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,300,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,301,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,302,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,303,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,304,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,305,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,306,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,307,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,308,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,309,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,310,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
2,311,1.108046193,163.338251,0.039636316,151.1111674,152.6507234,155.0180729,158.9651429,163.338251,167.6987436,171.6128653,173.9506901,175.4671292
";

    #endregion data helpers
}